
/**
 * A music track with a name, a duration and a genre.
 * 
 * NOTE: DO NOT CHANGE THIS CLASS
 * 
 * @author Malcolm Ryan 
 * @version Aug 23 2011
 */
public class Track
{
    // the possible genre values
    public final static int ROCK = 0;
    public final static int ALTERNATIVE = 1;
    public final static int JAZZ = 2;
    public final static int FOLK = 3;
    public final static int CLASSICAL = 4;
    public final static int WORLD = 5;
    public final static int ELECTRONICA = 6;
    public final static int HIP_HOP = 7;
    public final static int COUNTRY = 8;
    public final static int BLUES = 9;

    private String myName;
    private int myGenre;
    private int myDuration; // in seconds

    /**
     * Create a new track with given name, genre and duration
     */
    
    public Track(String name, int genre, int duration) {
        myName = name;
        myGenre = genre;
        myDuration = duration;
    }
    
    public String getName() {
        return myName;
    }
    
    public int getGenre() {
        return myGenre;
    }

    public int getDuration() {
        return myDuration;
    }
    
    public String toString() {
        int hours = myDuration / 3600;
        int minutes = (myDuration / 60) % 60; 
        int seconds = myDuration % 60;
        
        String result = myName + " - ";
        
        // omit hours if it is zero
        if (hours > 0) {
            result += hours + ":";

            // pad minutes 0-9 with a leading zero. 00 - 09
            if (minutes < 10) {
                result += "0";
            }        
        }
        
        result += minutes + ":";
        
        // pad seconds 0-9 with a leading zero. 00 - 09
        if (seconds < 10) {
            result += "0";
        }
        result += seconds;
        
        return result;
    }
}
